@@ -6,7 +6,7 @@ SNMP::Effective - An effective SNMP-information-gathering module
 
 =head1 VERSION
 
-1.10
+1.11
 
 =head1 SYNOPSIS
 
@@ -88,7 +88,7 @@ use POSIX qw(:errno_h);
 
 use base qw/ SNMP::Effective::Dispatch /;
 
-our $VERSION = eval '1.10';
+our $VERSION = '1.11';
 our %SNMPARG = (
     Version => '2c',
     Community => 'public',
@@ -279,6 +279,8 @@ sub add {
         }
     }
 
+    $in{'arg'} ||= delete $in{'args'};
+
     if(ref $in{'desthost'} eq 'ARRAY') {
         for my $addr (@{$in{'desthost'}}) {
 
@@ -286,7 +288,7 @@ sub add {
             my $host = $hostlist->get_host($addr)
                     || $hostlist->add_host(
                            address => $addr,
-                           arg => $in{'args'} || $self->arg,
+                           arg => $in{'arg'} || $self->arg,
                            callback => $in{'callback'} || $self->callback,
                            heap => $in{'heap'} || $self->heap,
                        );
@@ -591,3 +593,6 @@ under the same terms as Perl itself.
 =cut
 
 1;
+
+
+1;
